## replication file for "Measuring Explicit Political Positions of Media"
##
## one should be able simply type: source("QJPSreplication.R") at the
## R command prompt to replicate all the figures and analysis in the
## paper. 
##
## Kevin Quinn and Daniel Ho
## 10/12/2008
##


###########################################################################
## control switches
fit <- FALSE        ## should IRT models be fit?
pdfswitch <- TRUE  ## should graphs be sent to pdf (TRUE) or eps (FALSE)
if(!pdfswitch){
setEPS()
}
###########################################################################



###########################################################################
## load some utility functions
source("functionsQJPS.R")
library(car)
###########################################################################



###########################################################################
## IRT analyis
y <- read.csv("votes.csv")
un.y <- read.csv("votes-with-unan.csv")

## dropping cases without editorials
edit.written <- apply(y[,10:ncol(y)],1,function(x){sum(is.na(x))!=length(x)})
drop.y <- y[edit.written,]

## dropping justices
nojust.y <- drop.y
nojust.y <- nojust.y[,10:ncol(y)]

## just justices all cases
just.y <- y[,1:9]

## just justices only cases with editorials
just.edit.y <- just.y[edit.written,]

## just justices only cases without editorials
just.noedit.y <- just.y[!edit.written,]

## high and low saliences cases
background <- read.csv("CaseBackgroundVotes.csv")
high.sal.ind <- background$value %in% c("civil rights", "first amendment")
low.sal.ind <- background$value %in% c("criminal procedure",
                                       "economic activity", "judicial power",
                                       "federal taxation", "federalism",
                                       "due process", "privacy", "unions",
                                       "attorneys", "miscellaneous",
                                       "interstate relations")
high.sal.y <- background[high.sal.ind, 6:ncol(background)]
low.sal.y <- background[low.sal.ind, 6:ncol(background)]



library(coda)
library(MCMCpack)


if (fit){

## basic analysis
irt.out <- MCMCirt1d(t(y), theta.constraints=list(thomas="+", scalia="+",
                             stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.out, file="QJPSirtresults.Rdata")

## analysis with unanimous cases
irt.unan.out <- MCMCirt1d(t(un.y), theta.constraints=list(thomas="+",
                                     scalia="+",
                             stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.unan.out, file="QJPSirtresults-unan.Rdata")


## analysis after dropping cases without editorials
irt.drop.out <- MCMCirt1d(t(drop.y), theta.constraints=list(thomas="+",
                             scalia="+", stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.drop.out, file="QJPSirtresults-drop.Rdata")


## analysis excluding justices
irt.nojust.out <- MCMCirt1d(t(nojust.y), theta.constraints=list(nyp="+",
                             nyt="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.nojust.out, file="QJPSirtresults-nojust.Rdata")



## analysis with just justices all cases
irt.just.out <- MCMCirt1d(t(just.y), theta.constraints=list(thomas="+",
                             scalia="+", stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.just.out, file="QJPSirtresults-just.Rdata")


## analysis with just justices only editorials
irt.just.edit.out <- MCMCirt1d(t(just.edit.y),
                               theta.constraints=list(thomas="+",
                             scalia="+", stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.just.edit.out, file="QJPSirtresults-just-edit.Rdata")


## analysis with just justices only editorials
irt.just.noedit.out <- MCMCirt1d(t(just.noedit.y),
                               theta.constraints=list(thomas="+",
                             scalia="+", stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.just.noedit.out, file="QJPSirtresults-just-noedit.Rdata")


## high salience cases
irt.high.sal.out <- MCMCirt1d(t(high.sal.y),
                     theta.constraints=list(thomas="+", scalia="+",
                             stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.high.sal.out, file="QJPSirtresults-high-sal.Rdata")

## low salience cases
irt.low.sal.out <- MCMCirt1d(t(low.sal.y),
                     theta.constraints=list(thomas="+", scalia="+",
                             stevens="-"), AB0=.2,
                     burnin=50000,
                     mcmc=4000000,
                     thin=1000,
                     verbose=5000,
                     store.item=TRUE)#,

                                        #just to be able to test graphics
                     #burnin=0,
                     #mcmc=1000, thin=1,
                     #verbose=100, store.item=TRUE)

save(irt.low.sal.out, file="QJPSirtresults-low-sal.Rdata")





}





load("QJPSirtresults.Rdata")
load("QJPSirtresults-unan.Rdata")
load("QJPSirtresults-drop.Rdata")
load("QJPSirtresults-nojust.Rdata")
load("QJPSirtresults-just.Rdata")
load("QJPSirtresults-just-edit.Rdata")
load("QJPSirtresults-just-noedit.Rdata")
load("QJPSirtresults-high-sal.Rdata")
load("QJPSirtresults-low-sal.Rdata")



###########################################################################






###########################################################################
## plots derived from IRT analysis

#Preparing quantiles and names
nams <- names(y)
nams[nams%in%names(y)[10:ncol(y)]] <- toupper(nams[nams%in%names(y)[10:ncol(y)]])
nams <- paste(toupper(substr(nams,1,1)),
              substr(nams,2,20),sep="")
nams[nams=="Oconnor"] <- "O'Connor"
qs <- apply(irt.out[,1:34],2,quantile,probs=c(0.025,0.2,0.5,0.8,0.975))
dimnames(qs)[[2]] <- nams
N <- ncol(qs)
qs <- qs[,order(qs[3,])]
qcol <- rep("black",N)
qcol[dimnames(qs)[[2]]%in%toupper(c("nyt","wp","wt","lat","usa","wsj","hc",
                                    "dmn",
                                    "cst", "bg", "inv","ar","sdut",
                                    "sfc",
                                    "mst", "nyp", "ct",
                                    "cpd", "dfp","mh", "rmn", "pi", "aj",
                                    "ajc", "ac"))] <- gray(0.45)
qpch <- rep(16, N)
qpch[dimnames(qs)[[2]]%in%toupper(c("nyt","wp","wt","lat","usa","wsj","hc",
                                    "dmn",
                                    "cst", "bg", "inv","ar","sdut",
                                    "sfc",
                                    "mst", "nyp", "ct",
                                    "cpd", "dfp","mh", "rmn", "pi", "aj",
                                    "ajc", "ac"))] <- 3

if(pdfswitch){
  pdf("irt-almostall.pdf",height=6,width=12, bg="white", family="Helvetica")
}else{
  postscript("irt-almostall.eps", height=6,width=12, bg="white")
}

layout(matrix(c(rep(1,2),2:3),2,2,byrow=F),heights=c(0.83,0.17),
       widths=c(0.5,0.5))
par(mar=c(5, 6, 4, 2) + 0.1, mgp=c(3,1,0))
plot(qs[3,],1:N, col=qcol, 
     xlim=range(qs), ylab="",xlab="Ideology",
     axes=F, main="Ideal Point Estimates",ylim=c(-1,N), pch=qpch)
abline(h=1:N,col="lightgrey",lty=2,lwd=0.8)
points(qs[3,],1:N,pch=qpch, col=qcol)
segments(qs[1,],1:N,
         qs[5,],1:N, col=qcol)
segments(qs[2,],1:N, lwd=2,
         qs[4,],1:N, col=qcol)
mtext(side=2,line=0.5,at=1:N,text=dimnames(qs)[[2]],las=2,
      cex=0.8,col=qcol)

mtext(side=2,line=0.5,at=-1,text="Prior",las=2,cex=0.8)
prior.qs <- quantile(rnorm(10000,sd=1),probs=c(0.025,0.2,0.5,0.8,0.975))
points(prior.qs[3],-1,pch=16,col="darkgrey")
segments(prior.qs[1],-1,prior.qs[5],-1,col="darkgrey")
segments(prior.qs[2],-1,prior.qs[4],-1,lwd=2,col="darkgrey")
axis(1)
box()

## here, add rank probability panel
plot.posterior.ranks.theta(y, irt.out, plotcex=1.75)
dev.off()











## sensitivity analysis plots
paper.names <- colnames(y)[10:ncol(y)]

draws.basic <- matrix(NA, nrow(irt.out), length(paper.names))
for (i in 1:ncol(draws.basic)){
  draws.basic[,i] <- irt.out[, grep(paste("theta\\.", paper.names[i], "$",
                                          sep=""),
                                    dimnames(irt.out)[[2]])]
}
draws.basic <- draws.basic[sample(1:nrow(irt.out), 1000),]
colnames(draws.basic) <- paper.names


draws.unan <- matrix(NA, nrow(irt.unan.out), length(paper.names))
for (i in 1:ncol(draws.unan)){
  draws.unan[,i] <- irt.unan.out[, grep(paste("theta\\.", paper.names[i], "$",
                                          sep=""),
                                    dimnames(irt.unan.out)[[2]])]
}
draws.unan <- draws.unan[sample(1:nrow(irt.unan.out), 1000),]
colnames(draws.unan) <- paper.names


draws.drop <- matrix(NA, nrow(irt.drop.out), length(paper.names))
for (i in 1:ncol(draws.drop)){
  draws.drop[,i] <- irt.drop.out[, grep(paste("theta\\.", paper.names[i], "$",
                                          sep=""),
                                    dimnames(irt.drop.out)[[2]])]
}
draws.drop <- draws.drop[sample(1:nrow(irt.drop.out), 1000),]
colnames(draws.drop) <- paper.names


draws.nojust <- matrix(NA, nrow(irt.nojust.out), length(paper.names))
for (i in 1:ncol(draws.nojust)){
  draws.nojust[,i] <- irt.nojust.out[, grep(paste("theta\\.", paper.names[i],
                                                  "$", sep=""),
                                    dimnames(irt.nojust.out)[[2]])]
}
draws.nojust <- draws.nojust[sample(1:nrow(irt.nojust.out), 1000),]
colnames(draws.nojust) <- paper.names


draws.basic.just <- irt.out[,1:9]
draws.basic.just <- draws.basic.just[sample(1:nrow(irt.out), 1000),]

draws.just <- irt.out[,1:9]
draws.just <- draws.just[sample(1:nrow(irt.just.out), 1000),]

draws.just.unan <- irt.unan.out[,1:9]
draws.just.unan <- draws.just.unan[sample(1:nrow(irt.unan.out), 1000),]

draws.just.edit <- irt.just.edit.out[,1:9]
draws.just.edit <- draws.just.edit[sample(1:nrow(irt.just.edit.out), 1000),]

draws.just.noedit <- irt.just.noedit.out[,1:9]
draws.just.noedit <- draws.just.noedit[sample(1:nrow(irt.just.noedit.out),
                                              1000),]

draws.just.high <- irt.high.sal.out[,1:9]
draws.just.high <- draws.just.high[sample(1:nrow(irt.high.sal.out),
                                              1000),]

draws.just.low <- irt.low.sal.out[,1:9]
draws.just.low <- draws.just.low[sample(1:nrow(irt.low.sal.out),
                                              1000),]


## high and low sensitivity cases
draws.high <- matrix(NA, nrow(irt.high.sal.out), length(paper.names))
for (i in 1:ncol(draws.high)){
  draws.high[,i] <- irt.high.sal.out[, grep(paste("theta\\.", paper.names[i],
                                                  "$",
                                                  sep=""),
                                            dimnames(irt.high.sal.out)[[2]])]
}
draws.high <- draws.high[sample(1:nrow(irt.high.sal.out), 1000),]
colnames(draws.high) <- paper.names

draws.low <- matrix(NA, nrow(irt.low.sal.out), length(paper.names))
for (i in 1:ncol(draws.low)){
  draws.low[,i] <- irt.low.sal.out[, grep(paste("theta\\.", paper.names[i],
                                                  "$",
                                                  sep=""),
                                            dimnames(irt.low.sal.out)[[2]])]
}
draws.low <- draws.low[sample(1:nrow(irt.low.sal.out), 1000),]
colnames(draws.low) <- paper.names






if(pdfswitch){
  pdf("sensit.pdf", height=16*.6, width=8*.6, bg="white", family="Helvetica")
}else{
  postscript("sensit.eps", height=16*.6, width=8*.6, bg="white")
}

par(mfrow=c(4,2))
par(mar=c(5,6,4,2)+0.1)


plot(apply(draws.basic, 2, median), apply(draws.nojust, 2, median),
     ylim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     xlim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     main="Excluding Justices",
     xlab="All Nonunanimous Cases",
     ylab="Justices Excluded",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.basic)){
  data.ellipse(draws.basic[,i], draws.nojust[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.basic, 2, median)
local.y <- apply(draws.nojust, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))


plot(apply(draws.basic.just, 2, median), apply(draws.just, 2, median),
     ylim=range(cbind(draws.basic.just, draws.just, draws.just.edit,
       draws.just.noedit)),
     xlim=range(cbind(draws.basic.just, draws.just, draws.just.edit,
       draws.just.noedit)),
     main="Excluding Newspapers",
     xlab="All Nonunanimous Cases",
     ylab="Newspapers Excluded",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.basic.just)){
  data.ellipse(draws.basic.just[,i], draws.just[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.basic.just, 2, median)
local.y <- apply(draws.just, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))



plot(apply(draws.high, 2, median), apply(draws.low, 2, median),
     ylim=range(cbind(draws.basic, draws.high, draws.low)),
     xlim=range(cbind(draws.basic, draws.high, draws.low)),
     main="Case Salience",
     xlab="High Salience Cases",
     ylab="Lower Salience Cases",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.high)){
  data.ellipse(draws.high[,i], draws.low[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.high, 2, median)
local.y <- apply(draws.low, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))



plot(apply(draws.just.high, 2, median), apply(draws.just.low, 2, median),
     ylim=range(cbind(draws.basic.just, draws.just, draws.just.edit,
       draws.just.noedit)),
     xlim=range(cbind(draws.basic.just, draws.just, draws.just.edit,
       draws.just.noedit)),
     main="Case Salience",
     xlab="High Salience Cases",
     ylab="Lower Salience Cases",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.just.high)){
  data.ellipse(draws.just.high[,i], draws.just.low[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.just.high, 2, median)
local.y <- apply(draws.just.low, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))





plot(apply(draws.basic, 2, median), apply(draws.drop, 2, median),
     ylim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     xlim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     main="Excluding Cases\nWithout Editorials",
     xlab="All Nonunanimous Cases",
     ylab="Cases With Editorials",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.basic)){
  data.ellipse(draws.basic[,i], draws.drop[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.basic, 2, median)
local.y <- apply(draws.drop, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))



plot(apply(draws.basic.just, 2, median), apply(draws.just.edit, 2, median),
     ylim=range(cbind(draws.basic.just, draws.just, draws.just.edit,
       draws.just.noedit)),
     xlim=range(cbind(draws.basic.just, draws.just, draws.just.edit,
       draws.just.noedit)),
     main="Excluding Newspapers &\nCases Without Editorials",
     xlab="All Nonunanimous Cases",
     ylab="Cases With Editorials",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.basic.just)){
  data.ellipse(draws.basic.just[,i], draws.just.edit[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.basic.just, 2, median)
local.y <- apply(draws.just.edit, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))


plot(apply(draws.basic, 2, median), apply(draws.unan, 2, median),
     ylim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     xlim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     main="Unanimous Cases",
     xlab="All Nonunanimous Cases",
     ylab="Unanimous and\n Nonunanimous Cases",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.basic)){
  data.ellipse(draws.basic[,i], draws.unan[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.basic, 2, median)
local.y <- apply(draws.unan, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))


plot(apply(draws.just, 2, median), apply(draws.just.unan, 2, median),
     ylim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     xlim=range(cbind(draws.basic, draws.drop, draws.unan, draws.nojust)),
     main="Unanimous Cases",
     xlab="All Nonunanimous Cases",
     ylab="Unanimous and\n Nonunanimous Cases",
     type="n")
abline(0,1,col="gray")
for(i in 1:ncol(draws.just)){
  data.ellipse(draws.just[,i], draws.just.unan[,i],
               plot.points=F,levels=0.95,add=T,
               col="black", lwd=1, center.cex=1, center.pch=16)
}

local.x <- apply(draws.just, 2, median)
local.y <- apply(draws.just.unan, 2, median)
text(-2,2,eval(substitute(expression(paste(r,"=",RR,sep="")),
     list(RR=signif(cor(local.x, local.y),4)))))





dev.off()






























## Mondo and Groseclose-Milyo comparison

mondodata <- read.csv("mondo.csv")

gm.pt <- c(70,73.7,63.4,85.1,66.6,35.4)
gm.se <- c(2.2,1.6,2.7,3.9,2.5,2.7)
gm <- data.frame(lo=gm.pt-1.96*gm.se,
                 mid=gm.pt,
                 hi=gm.pt+1.96*gm.se)
gm <- data.frame(t(gm))
names(gm) <- toupper(c("lat","nyt","usa","wsj","wp","wt"))
simgm <- matrix(NA,1000,ncol(gm))
for(i in 1:ncol(gm)){
  simgm[,i] <- rnorm(1000,mean=gm.pt[i],sd=gm.se[i])
}

#ho quinn scores
hq <- qs[c(1,3,5),names(gm)]
simhq <- matrix(NA,nrow(irt.out),ncol(gm))
for(i in 1:ncol(gm)){
  simhq[,i] <- irt.out[,grep(tolower(names(gm)[i]),dimnames(irt.out)[[2]])]
}
simhq <- simhq[sample(1:nrow(irt.out),1000),]


#Mondo
select.inds <- match(dimnames(qs)[[2]],
                     toupper(as.character(mondodata$code)))
select.inds <- select.inds[!is.na(select.inds)]
mondo <- mondodata$mondoideology[select.inds]
mondo <- recode(mondo, recodes="'liberal'=1; 'leans left'=2; 'no bias'=3; 'leans right'=4; 'conservative'=5") 

irt.post.median <- qs[3, colnames(qs) %in% toupper(mondodata$code)]
irt.post.lower <- qs[1, colnames(qs) %in% toupper(mondodata$code)]
irt.post.upper <- qs[5, colnames(qs) %in% toupper(mondodata$code)]

if(pdfswitch){
  pdf("compare2.pdf", height=4.5, width=12, bg="white",
      version="1.4", family="Helvetica")
}else{
  postscript("compare2.eps", height=4.5,width=12, bg="white")
}

  set.seed(1234)
par(mfrow=c(1,3))

# Peake
peake <- read.csv("Peake.csv")
peake$symbol <- as.character(peake$symbol)

## Mondo vs. IRT
par(mar=c(5, 7.5, 4, 2) + 0.1)
mondojit <- jitter(as.numeric(mondo))
plot(irt.post.median, mondojit ,pch=16, axes=F,
     xlab="IRT Scores",
     ylab="",
     main="User Ratings of Political Bias",
     ylim=c(0.5, 5.5),
     xlim=range(qs[,!is.na(mondo)]), col="black")
segments(irt.post.lower,
         mondojit,
         irt.post.upper,
         mondojit,col="black")
m1 <- lm(as.numeric(mondo)~irt.post.median)
abline(m1)
text(jitter(irt.post.median, amount=0.2),
     jitter(mondojit,amount=0.2)-0.1,
     labels=names(irt.post.median),col="black")
mtext(side=2,line=0.5,at=1:5,text=c("liberal","leans left", "no bias", "leans right", "conservative"),las=2, cex=0.8)
mtext(side=2,line=6.35,text="Mondo Political Bias")
axis(1)
box()

## GM vs. IRT
par(mar=c(5, 4, 4, 2) + 0.1)
plot(hq[2,],gm[2,],pch=16, type="n",
     ylim=rev(range(gm)),
     xlim=range(hq),
     ylab="Groseclose & Milyo News Slant",
     xlab="IRT Scores",
     main="News Slant Via Think Tank Citations")
##45 degree line
##pu <- par("usr")
##m1 <- lm(pu[3:4] ~ pu[1:2])
m1 <- lm(as.numeric(gm[2,-4])~as.numeric(hq[2,-4]))
abline(m1)
for(i in 1:ncol(gm)){
data.ellipse(simhq[,i],simgm[,i],
             plot.points=F,levels=0.95,add=T,
             col="black",lwd=1)
}
abline(h=54,lty=2)
text(-1.5,52,"Groseclose & Milyo Center")
abline(v=median(irt.out[,grep("oconnor",dimnames(irt.out)[[2]])]),lty=2)
text(median(irt.out[,grep("oconnor",dimnames(irt.out)[[2]])])+0.08,82,srt=90,
     "Justice O'Connor")
abline(v=median(irt.out[,grep("breyer",dimnames(irt.out)[[2]])]),lty=2)
text(median(irt.out[,grep("breyer",dimnames(irt.out)[[2]])])+0.08,82,srt=90,
     "Justice Breyer")
text(hq[2,]-0.15,gm[2,]+2.5,names(gm))


## Peake headline tone

irt.post.median <- qs[3, peake$symbol]
irt.post.lower <- qs[1, peake$symbol]
irt.post.upper <- qs[5, peake$symbol]

par(mar=c(5, 4, 4, 2) + 0.1)
plot(irt.post.median, peake$HLTone, pch=16, ylim=c(0.25,2.1),
     xlim=range(irt.post.lower, irt.post.upper),
     xlab="IRT Scores", ylab="Peake's Headline Tone", main="Headline Tone")
segments(irt.post.lower,
         peake$HLTone,
         irt.post.upper,
         peake$HLTone, col="black")
text(jitter(irt.post.median, amount=0.2),
     jitter(peake$HLTone,amount=0.05)-0.025,
     labels=names(irt.post.median),col="black")
m1 <- lm(peake$HLTone~irt.post.median)
abline(m1)
dev.off()






## density plot of ideal points without WT,  INV, AJ, and AC
circ.data <- read.csv("circulation2002.csv")

papers <- 10:32       
papers <- papers[-c(3, 14, 23, 24)]
df2 <- dist.fun.theta(irt.out,
                      papers=papers,
                      from=-3,to=3,
                      by=.07)

weights <- circ.data$circulation2002
names(weights) <- circ.data$symbol
df2.weighted <- dist.fun.theta(irt.out,
                               papers=papers,
                               weights=weights, from=-3, to=3,
                               by=.07)


jud <- apply(irt.out[,1:9], 2, median)

jnam <- c("Rehnquist", "Stevens", "O'Connor", "Scalia", "Kennedy",
          "Souter", "Thomas", "Ginsburg", "Breyer")
djust <- list()
dall <- NULL
for(i in 1:9){
  djusti <- density(irt.out[,i])
  dall <- c(dall,djusti$y)
  djust <- c(djust,list(djusti))
}
if(pdfswitch){
  pdf("densityplot-dropINVWTAJAC.pdf",
      height=6, width=12, bg="white", version="1.4", family="Helvetica")
}else{
  postscript("densityplot-dropINVWTAJAC.eps", height=6,width=12, bg="white")
}

layout(matrix(1:2,2,1),heights=c(2.2,1))


par(mar=c(0, 4, 4, 2) + 0.1)
plot.expected.density.theta(df2,
                            insidecolor="darkgray",
                            axes=F,
                            ylim=c(0,1), main="All Top Newspapers")
arrows(jud,1,jud,-0.01,length=0.05,col="black",lty=2)
axis(2)
plot.expected.density.theta(df2.weighted,
                            linecolor="black",
                            lines.only=T)
text(1.4,0.3,"Weighted by Circulation",col="black")
text(-0.2,0.62,"Unweighted",col="darkgray")


par(mar=c(4, 4, 0, 2) + 0.1)
plot(1:10,1:10,ylim=c(0,max(dall)),type="n",
     xlim=range(df2[,"evalpoints"]),
     ylab="Density",xlab="Political Position")
for(i in 1:9){
  lines(djust[[i]],col="darkgray")
}
for(i in 1:9){
  if(!i%in%c(6,8,9)){
    text(jud[i],mean(djust[[i]]$y)+1.5,jnam[i],srt=90)
  } else if(i==9){
    text(jud[i]+0.12,mean(djust[[i]]$y)+1.5,jnam[i],srt=90)
  } else if(i%in%c(6,8)){
    text(jud[i]-0.1,mean(djust[[i]]$y)+1.5,jnam[i],srt=90)
  }
}
text(0,5,"Justices",font=2)

dev.off()





###########################################################################








###########################################################################
## summary plots
news.sum <- read.csv("newspaperSummary.csv")

if(pdfswitch){
  pdf("newstable.pdf", height=4, width=10, bg="white", family="Helvetica")
}else{
  postscript("newstable.eps", height=4,width=10, bg="white")
}


npap <- nrow(news.sum)
layout(matrix(1:5, 1, 5), widths=c(1.7, 0.5, 2, 2, 2))
par(mar=c(3, 0.3, 3, 0.3))

## 1: Newspaper name
plot(sample(c(1,10), npap, replace=T), 1:npap, axes=F, type="n",
     ylab="",xlab="")
mtext("Newspaper", font=2, line=0.5)
text(10, 1:npap, news.sum$Newspaper, pos=2, cex=1.2)


## 2: Newspaper code
plot(sample(c(1,10), npap, replace=T), 1:npap, axes=F, type="n",
     ylab="", xlab="")
mtext("Code", font=2, line=0.5)
text(1, 1:npap, news.sum$Code, pos=4, cex=1.2)


## 3: Newspaper circulation
plot(news.sum$Circulation/1000, 1:npap, axes=F, type="n",
     ylab="", xlab="")
abline(h=1:npap, col="darkgrey", lty=2)
abline(v=seq(from=500,to=2000,by=500), col="darkgrey")
segments(0, 1:npap, news.sum$Circulation/1000, 1:npap,
         lwd=4)
mtext("Circulation (1000s)", font=2, line=0.5)
axis(1)
box()


## 4: Observation Period
plot(news.sum$begin, 1:npap,axes=F, type="n",
     ylab="", xlab="", xlim=c(1994,2004))
abline(h=1:npap, col="darkgrey", lty=2)
abline(v=seq(from=1994, to=2004, by=1), col="darkgrey")
segments(news.sum$begin,
         1:npap, news.sum$end, 1:npap, lwd=4)
mtext("Observation Period", font=2, line=0.5)
axis(1)
box()


## 5: Newspaper editorials
plot(news.sum$Editorials, 1:npap, axes=F, type="n",
     ylab="", xlab="")
abline(h=1:npap, col="darkgrey", lty=2)
abline(v=seq(from=20, to=100, by=20), col="darkgrey")
segments(0, 1:npap, news.sum$Editorials, 1:npap, lwd=4)
mtext("Editorials", font=2, line=0.5)
axis(1)
box()


dev.off()



###########################################################################












###########################################################################
## posterior predictions

theta <- irt.out[,grep("theta",dimnames(irt.out)[[2]])]
alpha <- irt.out[,grep("alpha",dimnames(irt.out)[[2]])]
beta <- irt.out[,grep("beta",dimnames(irt.out)[[2]])]

theta.mean <- apply(theta, 2, mean)
alpha.mean <- apply(alpha, 2, mean)
beta.mean <- apply(beta, 2, mean)

yhat <- matrix(NA, nrow(y), ncol(y))
correct.mat <- yhat
for (i in 1:nrow(yhat)){
  for (j in 1:ncol(yhat)){
    eta <- -alpha.mean[i] + beta.mean[i] * theta.mean[j]
    if (eta > 0){
      yhat[i,j] <- 1
    }
    else{
      yhat[i,j] <- 0
    }

    if (!is.na(y[i,j])){
      if(y[i,j] == yhat[i,j]){
        correct.mat[i,j] <- 1
      }
      else{
        correct.mat[i,j] <- 0
      }
    }
    
  } # end j loop
  cat("i = ", i, "of ", nrow(y), "\n")
} # end i loop

colnames(yhat) <- colnames(correct.mat) <- colnames(y)

## justices
print(mean(correct.mat[,1:9], na.rm=TRUE))

## newspapers
print(mean(correct.mat[,10:ncol(correct.mat)], na.rm=TRUE))

## overall
print(mean(correct.mat, na.rm=TRUE))

## by justice and newspaper
round(apply(correct.mat, 2, mean, na.rm=TRUE), 3)


## check distribution of alpha.mean and beta.mean given editorial written
## and editorial not written
edit.written <- apply(y[,10:ncol(y)],1,function(x){sum(is.na(x))!=length(x)})

alpha.mean.0 <- alpha.mean[!edit.written]
alpha.mean.1 <- alpha.mean[edit.written]

beta.mean.0 <- beta.mean[!edit.written]
beta.mean.1 <- beta.mean[edit.written]


if(pdfswitch){
  pdf("alphabetaByEditorial.pdf", height=5, width=10)
}else{
  postscript("alphabetaByEditorial.eps", height=5,width=10, bg="white")
}

par(mfrow=c(1,2))
plot(density(alpha.mean.0), xlab="posterior mean alpha", main="")
lines(density(alpha.mean.1), col="red", lty=2)
legend(-2, .12, c("with editorials", "no editorials"),
       col=c("red", "black"), lty=c(2,1))


plot(density(beta.mean.0), xlab="posterior mean beta", main="")
lines(density(beta.mean.1), col="red", lty=2)
legend(-2, .05, c("with editorials", "no editorials"),
       col=c("red", "black"), lty=c(2,1))
dev.off()


###########################################################################






###########################################################################
## check balance on some background variables across editorial and no
## editorial cases

background <- read.csv("CaseBackgroundVotes.csv")
edit.written <- apply(background[,15:ncol(background)],1,function(x){sum(is.na(x))!=length(x)})

background.0 <- background[!edit.written,2:5]
background.1 <- background[edit.written,2:5]


bg.1 <- rbind(table(background.1[,1])/nrow(background.1),
              table(background.0[,1])/nrow(background.0))
rownames(bg.1) <- c("Editorial", "No Editorial")
colnames(bg.1) <- c("lctdir=0", "lctdir=1")


bg.2 <- rbind(table(background.1[,2])/nrow(background.1),
              table(background.0[,2])/nrow(background.0))
rownames(bg.2) <- c("Editorial", "No Editorial")
colnames(bg.2) <- toupper(colnames(bg.2))
bg.2.ord <- order(apply(bg.2, 2, mean))
bg.2 <- bg.2[,bg.2.ord]


bg.3 <- rbind(table(background.1[,3])/nrow(background.1),
              table(background.0[,3])/nrow(background.0))
rownames(bg.3) <- c("Editorial", "No Editorial")

bg.4 <- rbind(table(background.1[,4])/nrow(background.1),
              table(background.0[,4])/nrow(background.0))
rownames(bg.4) <- c("Editorial", "No Editorial")

library(lattice)
ltheme <- canonical.theme(color = FALSE)  
lattice.options(default.theme = ltheme)

if(pdfswitch){
  pdf("balance1.pdf", height=6, width=8, family="Helvetica")
}else{
  postscript("balance1.eps", height=6,width=8, bg="white")
}

print(barchart(t(bg.1), stack=FALSE,
               xlab="Fraction",
               key=simpleKey(points=FALSE, rectangles=TRUE,
                 text=rownames(bg.1))))
dev.off()


if(pdfswitch){
  pdf("balance2.pdf", height=6, width=8, family="Helvetica")
}else{
  postscript("balance2.eps", height=6,width=8,bg="white")
}

print(barchart(t(bg.2), stack=FALSE,
         xlab="Fraction",
         key=simpleKey(points=FALSE, rectangles=TRUE,
           text=rownames(bg.2))))
dev.off()

if(pdfswitch){
pdf("balance3.pdf", height=6, width=8, family="Helvetica")
}else{
  postscript("balance3.eps", height=6,width=8, bg="white")
}

print(barchart(t(bg.3), stack=FALSE,
         xlab="Fraction",
         key=simpleKey(points=FALSE, rectangles=TRUE,
           text=rownames(bg.3))))
dev.off()

if(pdfswitch){
  pdf("balance4.pdf", height=6, width=8, family="Helvetica")
}else{
  postscript("balance4.eps", height=6,width=12, bg="white")
}

print(barchart(t(bg.4), stack=FALSE,
         xlab="Fraction",
         key=simpleKey(points=FALSE, rectangles=TRUE,
           text=rownames(bg.4))))
dev.off()



###########################################################################








###########################################################################
## presidential endorsements
endorse <- read.csv("PresEndorsements.csv")
endorse$X <- as.character(endorse$X)
end.dta <- NULL
theta.sub <- theta.mean[10:length(theta.mean)]
theta.sub.name <- NULL
for (i in 1:length(theta.sub)){
  theta.sub.name <- c(theta.sub.name, strsplit(names(theta.sub)[i],
                                               "theta.")[[1]][2])
}
names(theta.sub) <- theta.sub.name
for (i in 1:nrow(endorse)){
  holder <- cbind(theta.sub[endorse[i,1]], t(endorse[i,2:5]))
  end.dta <- rbind(end.dta, holder)
}

colnames(end.dta) <- c("HQ", "pres")
end.dta <- as.data.frame(end.dta)

glm.out <- glm(pres ~ HQ, family=binomial, data=end.dta)
print(summary(glm.out))


print(table(predict(glm.out, type="response") > .5, glm.out$y))

###########################################################################



