
#===================================================
# 
# Posterior rank probabilities
#
#===================================================



## plot.posterior.ranks.theta is used in the replication
## plot the posterior distribution over the ranks for all thetas
plot.posterior.ranks.theta <- function(yy, out, plotcex=1,
                                       pheight=7, pwidth=7,
                                       lheight=1.75, lwidth=pwidth, ...){

  #mycol <- rgb(red=    c(1, 1, 1, 1, 1, 1, .97, .85, .65, .55, .45),
  #           green = c(1, .948, .84, .676, .472, .240, .155, .085, 0, 0, 0),
  #           blue =  c(1, .740, .6, .46, .34, .24, .21, .187, .13, .1, .05)
  #           )

  mycol <- gray(11:1/11)
  
  
  #subsetting newspapers only
  paper <- names(yy)%in% c("usa","wsj","nyt","lat","wp","nyp",
                           "ct","hc","dmn","sfc", "cst","bg",
                           "ar","ajc","mst","pi","cpd","dfp",
                           "mh","sdut", "inv","wt","rmn","aj","ac", "ajcp",
                           "nytPRE", "nytPOST", "bgPRE", "bgPOST")
  nam.paper <- names(yy)[paper]
  
  theta <- out[,grep("theta", colnames(out))]
  theta <- theta[,paper]

  theta.median <- apply(theta, 2, median)
  ord.theta <- order(theta.median)
  theta.median <- theta.median[ord.theta]
  nam.paper <- nam.paper[ord.theta]
  theta <- theta[,ord.theta]
  
  ntheta <- ncol(theta)
  ndraws <- nrow(theta)

  rank.mat <- t(apply(theta, 1, rank))

  ## plot
  par(mar=c(5, 3, 4, 2) + 0.1, mgp=c(3,1,0))
  plot(1:ntheta, 1:ntheta, type="n",
       xlim=c(1, ntheta), ylim=c(1, ntheta), axes=FALSE,
       main="Newspaper Ranks", xlab="Posterior Rank", ylab="")
  mtext(side=2, line=0.5, at=1:ntheta, text=toupper(nam.paper), las=2,
        cex=0.8)
  mtext(side=1, line=0.5, at=1:ntheta, text=1:ntheta, las=2,
        cex=0.8)
  abline(h=1:ntheta, col="lightgray")
  abline(v=seq(from=1, to=ntheta, by=10), col="lightgray")

  for (i in 1:ntheta){
    rank.i.indic.mat <- t(sapply(rank.mat[,i], "==", 1:ntheta))
    post.rank.i <- apply(rank.i.indic.mat, 2, mean)

    post.rank.i <- 0.5*(post.rank.i>0.5)+post.rank.i*(1-(post.rank.i>0.5))
    local.col <- mycol[round((post.rank.i*20 + 1))]
    
    points(1:ntheta, rep(i, length(post.rank.i)), col=local.col, pch=15,
           cex=plotcex)
    
  }
  
  par(mar=c(4, 3, 1, 1) + 0.1, mgp=c(1,0.2,0),yaxt="n")
  newmat <- matrix(seq(0,0.5,by=.05),11,1)
  xx <- seq(0,0.5,by=0.05)
  image(x=xx, y=1, z=newmat, col=mycol, xlab="Probability", 
      ylab="", breaks=c(0, 0.025, 0.075, 0.125, 0.175, 0.225, 0.275,
                 0.325, 0.375, 0.425, 0.475, 0.5), xlim=c(0,0.5),axes=F)
  axis(1,at=seq(0,0.5,0.1),labels=c(seq(0,0.4,0.1),"0.5+"))
  mtext(side=3,line=0,"Legend",cex=0.8)

}








## estimate the distribution function of the ideal points along with its 95%
## pointwise credible intervals
##
## NB: 
dist.fun.theta <- function(out, from=-3, to=3, by=0.1, papers="all",
                           weights=NULL, ...){
  
  theta <- out[,grep("theta", colnames(out))]
  if (identical(papers, "all")){
    papers <- 10:ncol(theta)
  }
  theta <- theta[,papers,drop=FALSE]

  colnames(theta) <- gsub("theta\\.", "", colnames(theta))
  
  
  if (is.null(weights)){
    weights <- rep(1/ncol(theta), ncol(theta))
  }
  else{
    weights <- weights[colnames(theta)]
    weights <- weights / sum(weights)
  }
  
  
  gridvals <- seq(from=from, to=to, by=by)

  Fval.mean <- rep(0, length(gridvals))
  Fval.025 <- rep(0, length(gridvals))
  Fval.975 <- rep(0, length(gridvals))
  for (i in 1:length(Fval.mean)){
    Fval.mean[i] <- mean(apply(theta<=gridvals[i], 1,
                               weighted.mean, w=weights))
    Fval.025[i] <- quantile(apply(theta<=gridvals[i], 1, weighted.mean,
                                  w=weights), 0.025)
    Fval.975[i] <- quantile(apply(theta<=gridvals[i], 1, weighted.mean,
                                  w=weights), 0.975)
  }

  outmat <- cbind(Fval.025, Fval.mean, Fval.975, gridvals)
  colnames(outmat) <- c("Q025", "Mean", "Q975", "evalpoints")

  return(outmat)
  
}




## convert output of dist.fun.theta to histogram estimate of density
## usage: df <- dist.fun.theta(irt.out)
##        plot.expected.density.theta(df)
plot.expected.density.theta <- function(df, ylim=c(0,0.65),
                                        insidecolor="wheat", linecolor="blue",
                                        main="", lines.only=F,...){

  Fval <- df[,"Mean"]
  gridvals <- df[,"evalpoints"]
  gridwidth <- gridvals[2] - gridvals[1]

  xlim=c(min(gridvals), max(gridvals))
  
  Fval.dif <- Fval[2:length(Fval)] - Fval[1:(length(Fval)-1)]
  x <- gridvals[2:length(gridvals)]-(0.5*gridwidth)
  if(!lines.only){
    plot(1, 1, xlim=xlim, ylim=ylim, type="n", axes=F, xlab="",
         ylab="Density", main=main)
    polygon(c(x, rev(x)),
            c(Fval.dif/gridwidth, rep(0, length(Fval.dif))),
            col=insidecolor, border=insidecolor)
  } else { 
    lines(gridvals[2:length(gridvals)]-(0.5*gridwidth), Fval.dif/gridwidth,
          lwd=3, col=linecolor)
  }
  abline(h=0, col="darkgray")
}

## convert output of dist.fun.theta to plot of distribution function
## usage: df <- dist.fun.theta(irt.out)
##        plot.distribution.theta(df)
plot.distribution.theta <- function(df, insidecolor="wheat", linecolor="blue",
                                    ...){

  
  xlim=c(min(df[,"evalpoints"]), max(df[,"evalpoints"]))
  n <- nrow(df)

  x <- c(df[,"evalpoints"], rev(df[,"evalpoints"]))
  y <- c(df[,"Q975"], rev(df[,"Q025"]))
  
  plot(1, 1, type="n", xlim=xlim, ylim=c(0,1))
  grid()
  polygon(x, y, col=insidecolor)
  lines(df[,"evalpoints"], df[,"Mean"], col=linecolor, lwd=3)
  
}
